diff --git a/qa/pull-tester/rpc-tests.py b/qa/pull-tester/rpc-tests.py
index 6f39f49c9..553e6d4b3 100755
--- a/qa/pull-tester/rpc-tests.py
+++ b/qa/pull-tester/rpc-tests.py
@@ -280,7 +280,7 @@ def runtests():
class RPCTestHandler:
"""
- Trigger the testscrips passed in via the list.
+ Trigger the testscripts passed in via the list.
"""
def __init__(self, num_tests_parallel, test_list=None, flags=None):
diff --git a/src/qt/locale/bitcoin_fi.ts b/src/qt/locale/bitcoin_fi.ts
index 9eee52be7..2f11e5f9a 100644
--- a/src/qt/locale/bitcoin_fi.ts
+++ b/src/qt/locale/bitcoin_fi.ts
@@ -2570,7 +2570,7 @@ Use this functionality with extreme caution.
Clear &All
- &Tyhjennnä Kaikki
+ &Tyhjennä Kaikki
Balance:
diff --git a/src/qt/locale/bitcoin_nl.ts b/src/qt/locale/bitcoin_nl.ts
index c8787f839..f941e77ea 100644
--- a/src/qt/locale/bitcoin_nl.ts
+++ b/src/qt/locale/bitcoin_nl.ts
@@ -3775,7 +3775,7 @@ Gebruik deze functie met extreme voorzichtigheid.
Error initializing block database
- Fout bij intialisatie blokkendatabase
+ Fout bij initialisatie blokkendatabase
Error initializing wallet database environment %s!
diff --git a/qa/rpc-tests/rawtransactions.py b/qa/rpc-tests/rawtransactions.py
index c70f178a4..78c1ba01f 100755
--- a/qa/rpc-tests/rawtransactions.py
+++ b/qa/rpc-tests/rawtransactions.py
@@ -3,7 +3,7 @@
# Copyright (c) 2018-2022 The Dogecoin Core developers
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-"""rawtranscation RPCs QA test.
+"""rawtransaction RPCs QA test.
# Tests the following RPCs:
# - createrawtransaction
@@ -156,8 +156,8 @@ class RawTransactionsTest(BitcoinTestFramework):
# 5. valid parameters - supply txid and True for non-verbose
assert_equal(self.nodes[0].getrawtransaction(txHash, True)["hex"], rawTxSigned['hex'])
- # 6. invalid parameters - supply txid and string "Flase"
- assert_raises_jsonrpc(-3,"Invalid type", self.nodes[0].getrawtransaction, txHash, "Flase")
+ # 6. invalid parameters - supply txid and string "invalidstringvalue"
+ assert_raises_jsonrpc(-3,"Invalid type", self.nodes[0].getrawtransaction, txHash, "invalidstringvalue")
# 7. invalid parameters - supply txid and empty array
assert_raises_jsonrpc(-3,"Invalid type", self.nodes[0].getrawtransaction, txHash, [])